import { newVarInputVal } from "js/composer/varInputValManager";

export const dataCommands = {
  label: "数据处理",
  icon: "format_color_text",
  defaultOpened: false,
  commands: [
    {
      value: "quickcomposer.data.string.reverse",
      label: "字符串处理",
      desc: "字符串处理和转换",
      icon: "text_fields",
      subCommands: [
        {
          value: "quickcomposer.data.string.reverse",
          label: "字符串反转",
          icon: "swap_horiz",
          config: [
            {
              key: "text",
              label: "要反转的文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 12,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.replace",
          label: "字符串替换",
          icon: "find_replace",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 12,
            },
            {
              key: "oldStr",
              label: "要替换的文本",
              component: "VariableInput",
              icon: "find_replace",
              width: 6,
            },
            {
              key: "newStr",
              label: "替换为",
              component: "VariableInput",
              icon: "text_fields",
              width: 6,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.substring",
          label: "字符串截取",
          icon: "content_cut",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 12,
            },
            {
              key: "start",
              label: "起始位置",
              component: "NumberInput",
              min: 0,
              step: 1,
              icon: "first_page",
              width: 6,
            },
            {
              key: "end",
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              min: 0,
              step: 1,
              width: 6,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.trim",
          label: "去除空白",
          icon: "format_align_justify",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 8,
            },
            {
              key: "mode",
              label: "模式",
              component: "q-select",
              icon: "settings",
              options: [
                { label: "两端", value: "both" },
                { label: "左侧", value: "start" },
                { label: "右侧", value: "end" },
              ],
              defaultValue: "both",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.case",
          label: "大小写转换",
          icon: "text_fields",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 8,
            },
            {
              key: "mode",
              label: "转换为",
              component: "q-select",
              icon: "settings",
              options: [
                { label: "大写", value: "upper" },
                { label: "小写", value: "lower" },
                { label: "首字母大写", value: "capitalize" },
                { label: "驼峰", value: "camel" },
                { label: "蛇形", value: "snake" },
                { label: "短横线", value: "kebab" },
                { label: "常量", value: "constant" },
              ],
              defaultValue: "upper",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.pad",
          label: "字符串填充",
          icon: "format_size",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 12,
            },
            {
              key: "length",
              label: "目标长度",
              component: "NumberInput",
              min: 0,
              step: 1,
              icon: "straighten",
              width: 4,
            },
            {
              key: "padString",
              label: "填充字符",
              component: "VariableInput",
              icon: "space_bar",
              width: 4,
              defaultValue: newVarInputVal("str", " "),
            },
            {
              key: "mode",
              label: "填充位置",
              component: "q-select",
              icon: "settings",
              options: [
                { label: "左侧", value: "start" },
                { label: "右侧", value: "end" },
                { label: "两端", value: "both" },
              ],
              defaultValue: "end",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.split",
          label: "字符串分割",
          icon: "splitscreen",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 8,
            },
            {
              key: "separator",
              label: "分隔符",
              component: "VariableInput",
              icon: "space_bar",
              width: 4,
              defaultValue: newVarInputVal("str", ","),
            },
          ],
        },
        {
          value: "quickcomposer.data.string.join",
          label: "数组合并",
          icon: "merge",
          config: [
            {
              key: "array",
              label: "字符串数组",
              component: "VariableInput",
              icon: "view_list",
              width: 8,
            },
            {
              key: "separator",
              label: "连接符",
              component: "VariableInput",
              icon: "space_bar",
              width: 4,
              defaultValue: newVarInputVal("str", ","),
            },
          ],
        },
        {
          value: "quickcomposer.data.string.repeat",
          label: "字符串重复",
          icon: "copy_all",
          config: [
            {
              key: "text",
              label: "要重复的文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 8,
            },
            {
              key: "count",
              label: "重复次数",
              component: "NumberInput",
              min: 0,
              step: 1,
              icon: "repeat",
              width: 4,
              defaultValue: 1,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.extract",
          label: "提取字符",
          icon: "content_cut",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 8,
            },
            {
              key: "mode",
              label: "提取类型",
              component: "q-select",
              icon: "settings",
              options: [
                { label: "数字", value: "number" },
                { label: "字母", value: "letter" },
                { label: "中文", value: "chinese" },
                { label: "标点符号", value: "punctuation" },
                { label: "空白字符", value: "whitespace" },
              ],
              defaultValue: "number",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.count",
          label: "字符统计",
          icon: "numbers",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 8,
            },
            {
              key: "mode",
              label: "统计类型",
              component: "q-select",
              icon: "settings",
              options: [
                { label: "字符数", value: "char" },
                { label: "单词数", value: "word" },
                { label: "行数", value: "line" },
                { label: "数字数", value: "number" },
                { label: "字母数", value: "letter" },
                { label: "中文字数", value: "chinese" },
                { label: "空白字符数", value: "whitespace" },
              ],
              defaultValue: "char",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.wrap",
          label: "文本换行",
          icon: "wrap_text",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 8,
            },
            {
              key: "width",
              label: "每行字符数",
              component: "NumberInput",
              min: 1,
              step: 1,
              icon: "straighten",
              width: 4,
              defaultValue: 80,
            },
          ],
        },
        {
          value: "quickcomposer.data.string.align",
          label: "文本对齐",
          icon: "format_align_center",
          config: [
            {
              key: "text",
              label: "原始文本",
              component: "VariableInput",
              icon: "text_fields",
              width: 12,
            },
            {
              key: "mode",
              label: "对齐方式",
              component: "q-select",
              icon: "settings",
              options: [
                { label: "左对齐", value: "left" },
                { label: "居中", value: "center" },
                { label: "右对齐", value: "right" },
                { label: "两端对齐", value: "justify" },
              ],
              defaultValue: "left",
              width: 6,
            },
            {
              key: "width",
              label: "总宽度",
              component: "NumberInput",
              min: 1,
              step: 1,
              icon: "straighten",
              width: 6,
              defaultValue: 80,
            },
          ],
        },
      ],
    },
    {
      value: "quickcomposer.data.regexTransform",
      label: "正则提取/替换",
      component: "RegexEditor",
      componentProps: {
        inputLabel: "要处理的文本",
      },
      outputVariable: "processedText",
      saveOutput: true,
    },
    {
      value: "quickcomposer.data.buffer.from",
      label: "Buffer操作",
      desc: "Buffer创建、转换和操作",
      config: [],
      icon: "memory",
      subCommands: [
        {
          value: "quickcomposer.data.buffer.from",
          label: "创建Buffer",
          icon: "add_box",
          config: [
            {
              label: "数据",
              component: "VariableInput",
              icon: "text_fields",
              width: 9,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 3,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.toString",
          label: "转换字符串",
          icon: "text_fields",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 12,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              step: 1,
              icon: "first_page",
              width: 4,
            },
            {
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              step: 1,
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.write",
          label: "写入数据",
          icon: "edit",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
            {
              label: "要写入的字符串",
              component: "VariableInput",
              icon: "edit",
              width: 6,
            },
            {
              label: "偏移量",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "长度",
              component: "NumberInput",
              icon: "straighten",
              width: 4,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.fill",
          label: "填充数据",
          icon: "format_color_fill",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
            {
              label: "填充值",
              component: "VariableInput",
              icon: "format_color_fill",
              width: 6,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              width: 4,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.copy",
          label: "复制数据",
          icon: "content_copy",
          config: [
            {
              label: "源Buffer",
              component: "VariableInput",
              icon: "content_copy",
              width: 6,
            },
            {
              label: "目标Buffer",
              component: "VariableInput",
              icon: "save",
              width: 6,
            },
            {
              label: "目标起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "源起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "源结束位置",
              component: "NumberInput",
              icon: "last_page",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.compare",
          label: "比较数据",
          icon: "compare",
          config: [
            {
              label: "Buffer 1",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
            {
              label: "Buffer 2",
              component: "VariableInput",
              icon: "memory",
              width: 6,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.concat",
          label: "连接Buffer",
          icon: "merge",
          config: [
            {
              label: "Buffer",
              component: "ArrayEditor",
              icon: "memory",
              width: 12,
              defaultValue: [newVarInputVal("var")],
              defaultRowValue: newVarInputVal("var"),
              disableToggleType: true,
            },
            {
              label: "总长度（可选）",
              component: "NumberInput",
              icon: "straighten",
              width: 12,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.slice",
          label: "切片数据",
          icon: "content_cut",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 12,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 6,
            },
            {
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              width: 6,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.indexOf",
          label: "查找数据",
          icon: "search",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 12,
            },
            {
              label: "要查找的值",
              component: "VariableInput",
              icon: "search",
              width: 4,
            },
            {
              label: "起始位置",
              component: "NumberInput",
              icon: "first_page",
              width: 4,
            },
            {
              label: "编码",
              component: "q-select",
              icon: "code",
              options: [
                { label: "UTF-8", value: "utf8" },
                { label: "UTF-16LE", value: "utf16le" },
                { label: "Latin1", value: "latin1" },
                { label: "Base64", value: "base64" },
                { label: "Hex", value: "hex" },
                { label: "ASCII", value: "ascii" },
                { label: "Binary", value: "binary" },
                { label: "UCS-2", value: "ucs2" },
              ],
              defaultValue: "utf8",
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.buffer.swap",
          label: "交换字节序",
          icon: "swap_horiz",
          config: [
            {
              label: "Buffer",
              component: "VariableInput",
              icon: "memory",
              width: 9,
            },
            {
              label: "字节大小",
              component: "q-select",
              icon: "memory",
              options: [
                { label: "16位", value: 16 },
                { label: "32位", value: 32 },
                { label: "64位", value: 64 },
              ],
              defaultValue: 16,
              width: 3,
            },
          ],
        },
      ],
    },
    {
      value: "quickcomposer.data.zlib",
      label: "数据压缩解压",
      desc: "使用 zlib 进行数据压缩和解压",
      component: "ZlibEditor",
      icon: "compress",
      isAsync: true,
    },
    {
      value: "quickcomposer.data.htmlParser",
      label: "HTML解析",
      desc: "解析 HTML 字符串",
      icon: "html",
      config: [
        {
          label: "要解析的 HTML",
          component: "VariableInput",
          icon: "html",
          placeholder: "例如：<div>Hello, World!</div>",
          width: 12,
        },
        {
          label: "CSS选择器",
          component: "VariableInput",
          icon: "css",
          placeholder: "例如：.class",
          width: 7,
        },
        {
          label: "属性",
          component: "VariableInput",
          icon: "colorize",
          options: {
            items: [
              { label: "innerText", value: "innerText" },
              { label: "innerHTML", value: "innerHTML" },
              { label: "href", value: "href" },
              { label: "src", value: "src" },
              { label: "value", value: "value" },
            ],
          },
          defaultValue: newVarInputVal("str"),
          width: 5,
        },
      ],
    },
    {
      value: "JSON.stringify",
      label: "JSON处理",
      desc: "JSON处理",
      icon: "data_object",
      subCommands: [
        {
          value: "JSON.stringify",
          label: "JSON序列化",
          icon: "data_object",
          config: [
            {
              label: "要序列化的对象",
              component: "VariableInput",
              icon: "input",
              defaultValue: newVarInputVal("var"),
              disableToggleType: true,
              width: 12,
            },
            {
              label: "替换函数/指定属性",
              component: "VariableInput",
              icon: "swap_horiz",
              defaultValue: newVarInputVal("var", "null"),
              disableToggleType: true,
              width: 6,
            },
            {
              label: "缩进",
              component: "NumberInput",
              icon: "format_indent_increase",
              defaultValue: 2,
              step: 1,
              min: 0,
              width: 6,
            },
          ],
        },
        {
          value: "JSON.parse",
          label: "JSON反序列化",
          icon: "text_fields",
          config: [
            {
              label: "要反序列化的JSON字符串",
              component: "VariableInput",
              icon: "input",
              width: 12,
            },
          ],
        },
      ],
    },
    {
      value: "quickcomposer.data.array.filter",
      label: "数组处理",
      desc: "对象数组的常用操作",
      icon: "view_list",
      subCommands: [
        {
          value: "quickcomposer.data.array.filter",
          label: "数组过滤",
          icon: "filter_alt",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 12,
              defaultValue: newVarInputVal("var"),
              disableToggleType: true,
              placeholder:
                '[{"id":1,"name":"张三","age":20},{"id":2,"name":"李四","age":18}]',
            },
            {
              key: "condition",
              label: "过滤条件",
              component: "VariableInput",
              icon: "code",
              width: 12,
              placeholder: "age > 18",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.map",
          label: "数组映射",
          icon: "transform",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 12,
              placeholder:
                '[{"id":1,"name":"张三","age":20},{"id":2,"name":"李四","age":18}]',
            },
            {
              key: "transform",
              label: "转换函数",
              component: "VariableInput",
              icon: "code",
              placeholder: "name",
              width: 12,
            },
          ],
        },
        {
          value: "quickcomposer.data.array.sort",
          label: "数组排序",
          icon: "sort",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 12,
              placeholder:
                '[{"id":1,"name":"张三","age":20},{"id":2,"name":"李四","age":18}]',
            },
            {
              key: "key",
              label: "排序字段",
              component: "VariableInput",
              icon: "key",
              width: 6,
              placeholder: "age",
            },
            {
              key: "order",
              label: "排序方式",
              component: "q-select",
              icon: "sort",
              options: [
                { label: "升序", value: "asc" },
                { label: "降序", value: "desc" },
              ],
              defaultValue: "asc",
              width: 6,
            },
          ],
        },
        {
          value: "quickcomposer.data.array.group",
          label: "数组分组",
          icon: "group_work",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 8,
              placeholder:
                '[{"id":1,"name":"张三","dept":"技术"},{"id":2,"name":"李四","dept":"技术"}]',
            },
            {
              key: "key",
              label: "分组字段",
              component: "VariableInput",
              icon: "key",
              width: 4,
              placeholder: "dept",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.unique",
          label: "数组去重",
          icon: "filter_1",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 8,
              placeholder: '[{"id":1,"dept":"技术"},{"id":2,"dept":"技术"}]',
            },
            {
              key: "key",
              label: "去重字段",
              component: "VariableInput",
              icon: "key",
              width: 4,
              placeholder: "dept",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.find",
          label: "查找元素",
          icon: "search",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 12,
              placeholder: '[{"id":1,"name":"张三"},{"id":2,"name":"李四"}]',
            },
            {
              key: "condition",
              label: "查找条件",
              component: "VariableInput",
              icon: "code",
              width: 12,
              placeholder: "id === 1",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.aggregate",
          label: "数组聚合",
          icon: "functions",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 12,
              placeholder: '[{"id":1,"amount":100},{"id":2,"amount":200}]',
            },
            {
              key: "operation",
              label: "聚合操作",
              component: "q-select",
              icon: "functions",
              options: [
                { label: "求和", value: "sum" },
                { label: "平均值", value: "avg" },
                { label: "最大值", value: "max" },
                { label: "最小值", value: "min" },
                { label: "计数", value: "count" },
              ],
              defaultValue: "sum",
              width: 6,
            },
            {
              key: "key",
              label: "聚合字段",
              component: "VariableInput",
              icon: "key",
              width: 6,
              placeholder: "amount",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.slice",
          label: "数组切片",
          icon: "content_cut",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 12,
              placeholder: "[1,2,3,4,5]",
            },
            {
              key: "start",
              label: "起始位置",
              component: "NumberInput",
              icon: "first_page",
              min: 0,
              step: 1,
              width: 6,
              placeholder: "1",
            },
            {
              key: "end",
              label: "结束位置",
              component: "NumberInput",
              icon: "last_page",
              min: 0,
              step: 1,
              width: 6,
              placeholder: "3",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.flatten",
          label: "数组扁平化",
          icon: "unfold_less",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 8,
              placeholder: "[[1,2],[3,4],[[5,6]]]",
            },
            {
              key: "depth",
              label: "扁平化深度",
              component: "NumberInput",
              icon: "format_indent_decrease",
              min: 1,
              step: 1,
              defaultValue: 1,
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.array.diff",
          label: "数组差集",
          icon: "difference",
          config: [
            {
              key: "array1",
              label: "数组1",
              component: "VariableInput",
              icon: "view_list",
              width: 6,
              placeholder: "[1,2,3,4]",
            },
            {
              key: "array2",
              label: "数组2",
              component: "VariableInput",
              icon: "view_list",
              width: 6,
              placeholder: "[3,4,5,6]",
            },
            {
              key: "key",
              label: "比较字段",
              component: "VariableInput",
              icon: "key",
              width: 12,
              placeholder: "对象数组时使用，如: id",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.intersect",
          label: "数组交集",
          icon: "join_full",
          config: [
            {
              key: "array1",
              label: "数组1",
              component: "VariableInput",
              icon: "view_list",
              width: 6,
              placeholder: "[1,2,3,4]",
            },
            {
              key: "array2",
              label: "数组2",
              component: "VariableInput",
              icon: "view_list",
              width: 6,
              placeholder: "[3,4,5,6]",
            },
            {
              key: "key",
              label: "比较字段",
              component: "VariableInput",
              icon: "key",
              width: 12,
              placeholder: "对象数组时使用，如: id",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.union",
          label: "数组并集",
          icon: "join_inner",
          config: [
            {
              key: "array1",
              label: "数组1",
              component: "VariableInput",
              icon: "view_list",
              width: 6,
              placeholder: "[1,2,3,4]",
            },
            {
              key: "array2",
              label: "数组2",
              component: "VariableInput",
              icon: "view_list",
              width: 6,
              placeholder: "[3,4,5,6]",
            },
            {
              key: "key",
              label: "比较字段",
              component: "VariableInput",
              icon: "key",
              width: 12,
              placeholder: "对象数组时使用，如: id",
            },
          ],
        },
        {
          value: "quickcomposer.data.array.chunk",
          label: "数组分块",
          icon: "grid_view",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 8,
              placeholder: "[1,2,3,4,5,6]",
            },
            {
              key: "size",
              label: "块大小",
              component: "NumberInput",
              icon: "straighten",
              min: 1,
              step: 1,
              defaultValue: 2,
              width: 4,
            },
          ],
        },
        {
          value: "quickcomposer.data.array.shuffle",
          label: "数组随机排序",
          icon: "shuffle",
          config: [
            {
              key: "array",
              label: "原始数组",
              component: "VariableInput",
              icon: "view_list",
              width: 12,
              placeholder: "[1,2,3,4,5]",
            },
          ],
        },
      ],
    },
    {
      value: "quickcomposer.data.time.format",
      label: "时间处理",
      desc: "时间日期的常用操作",
      icon: "schedule",
      subCommands: [
        {
          value: "quickcomposer.data.time.format",
          label: "时间格式化",
          icon: "event",
          config: [
            {
              key: "time",
              label: "时间",
              component: "VariableInput",
              icon: "schedule",
              width: 8,
              placeholder: "2024-01-01 或 now 或 timestamp",
            },
            {
              key: "format",
              label: "格式",
              component: "q-select",
              icon: "format_shapes",
              width: 4,
              options: [
                { label: "YYYY-MM-DD", value: "YYYY-MM-DD" },
                { label: "YYYY-MM-DD HH:mm:ss", value: "YYYY-MM-DD HH:mm:ss" },
                { label: "YYYY年MM月DD日", value: "YYYY年MM月DD日" },
                { label: "MM/DD/YYYY", value: "MM/DD/YYYY" },
                { label: "DD/MM/YYYY", value: "DD/MM/YYYY" },
                { label: "HH:mm:ss", value: "HH:mm:ss" },
                { label: "YYYY-MM-DD HH:mm", value: "YYYY-MM-DD HH:mm" },
                { label: "时间戳(秒)", value: "timestamp" },
                { label: "时间戳(毫秒)", value: "timestamp_ms" },
                { label: "相对时间", value: "relative" },
              ],
              defaultValue: "YYYY-MM-DD HH:mm:ss",
            },
          ],
        },
        {
          value: "quickcomposer.data.time.parse",
          label: "时间解析",
          icon: "input",
          config: [
            {
              key: "time",
              label: "时间字符串",
              component: "VariableInput",
              icon: "schedule",
              width: 8,
              placeholder: "2024-01-01 12:00:00",
            },
            {
              key: "format",
              label: "原格式",
              component: "q-select",
              icon: "format_shapes",
              width: 4,
              options: [
                { label: "YYYY-MM-DD", value: "YYYY-MM-DD" },
                { label: "YYYY-MM-DD HH:mm:ss", value: "YYYY-MM-DD HH:mm:ss" },
                { label: "YYYY年MM月DD日", value: "YYYY年MM月DD日" },
                { label: "MM/DD/YYYY", value: "MM/DD/YYYY" },
                { label: "DD/MM/YYYY", value: "DD/MM/YYYY" },
                { label: "时间戳(秒)", value: "timestamp" },
                { label: "时间戳(毫秒)", value: "timestamp_ms" },
              ],
              defaultValue: "YYYY-MM-DD HH:mm:ss",
            },
          ],
        },
        {
          value: "quickcomposer.data.time.add",
          label: "时间加减",
          icon: "add",
          config: [
            {
              key: "time",
              label: "基准时间",
              component: "VariableInput",
              icon: "schedule",
              width: 12,
              placeholder: "2024-01-01 或 now",
            },
            {
              key: "value",
              label: "数值",
              component: "NumberInput",
              icon: "exposure",
              width: 6,
              defaultValue: 1,
            },
            {
              key: "unit",
              label: "单位",
              component: "q-select",
              icon: "straighten",
              width: 6,
              options: [
                { label: "年", value: "years" },
                { label: "月", value: "months" },
                { label: "周", value: "weeks" },
                { label: "天", value: "days" },
                { label: "小时", value: "hours" },
                { label: "分钟", value: "minutes" },
                { label: "秒", value: "seconds" },
              ],
              defaultValue: "days",
            },
          ],
        },
        {
          value: "quickcomposer.data.time.diff",
          label: "时间差值",
          icon: "difference",
          config: [
            {
              key: "time1",
              label: "时间1",
              component: "VariableInput",
              icon: "schedule",
              width: 6,
              placeholder: "2024-01-01",
            },
            {
              key: "time2",
              label: "时间2",
              component: "VariableInput",
              icon: "schedule",
              width: 6,
              placeholder: "2024-02-01",
            },
            {
              key: "unit",
              label: "返回单位",
              component: "q-select",
              icon: "straighten",
              width: 6,
              options: [
                { label: "年", value: "years" },
                { label: "月", value: "months" },
                { label: "周", value: "weeks" },
                { label: "天", value: "days" },
                { label: "小时", value: "hours" },
                { label: "分钟", value: "minutes" },
                { label: "秒", value: "seconds" },
                { label: "毫秒", value: "milliseconds" },
              ],
              defaultValue: "days",
            },
            {
              key: "absolute",
              label: "绝对值",
              component: "CheckButton",
              width: 6,
              defaultValue: true,
            },
          ],
        },
        {
          value: "quickcomposer.data.time.startOf",
          label: "时间边界",
          icon: "first_page",
          config: [
            {
              key: "time",
              label: "时间",
              component: "VariableInput",
              icon: "schedule",
              width: 6,
              placeholder: "2024-01-01 或 now",
            },
            {
              key: "unit",
              label: "单位",
              component: "q-select",
              icon: "straighten",
              width: 3,
              options: [
                { label: "年", value: "year" },
                { label: "月", value: "month" },
                { label: "周", value: "week" },
                { label: "天", value: "day" },
                { label: "小时", value: "hour" },
                { label: "分钟", value: "minute" },
                { label: "秒", value: "second" },
              ],
              defaultValue: "day",
            },
            {
              key: "type",
              label: "类型",
              component: "q-select",
              icon: "settings",
              width: 3,
              options: [
                { label: "开始", value: "start" },
                { label: "结束", value: "end" },
              ],
              defaultValue: "start",
            },
          ],
        },
        {
          value: "quickcomposer.data.time.isValid",
          label: "时间验证",
          icon: "check_circle",
          config: [
            {
              key: "time",
              label: "时间",
              component: "VariableInput",
              icon: "schedule",
              width: 8,
              placeholder: "2024-01-01",
            },
            {
              key: "format",
              label: "格式",
              component: "q-select",
              icon: "format_shapes",
              width: 4,
              options: [
                { label: "YYYY-MM-DD", value: "YYYY-MM-DD" },
                { label: "YYYY-MM-DD HH:mm:ss", value: "YYYY-MM-DD HH:mm:ss" },
                { label: "YYYY年MM月DD日", value: "YYYY年MM月DD日" },
                { label: "MM/DD/YYYY", value: "MM/DD/YYYY" },
                { label: "DD/MM/YYYY", value: "DD/MM/YYYY" },
              ],
              defaultValue: "YYYY-MM-DD",
            },
          ],
        },
        {
          value: "quickcomposer.data.time.calendar",
          label: "日历信息",
          icon: "calendar_month",
          config: [
            {
              key: "time",
              label: "时间",
              component: "VariableInput",
              icon: "schedule",
              width: 12,
              placeholder: "2024-01-01 或 now",
            },
          ],
        },
        {
          value: "quickcomposer.data.time.workday",
          label: "工作日计算",
          icon: "work",
          config: [
            {
              key: "startTime",
              label: "开始时间",
              component: "VariableInput",
              icon: "schedule",
              width: 4,
              placeholder: "2024-01-01",
            },
            {
              key: "days",
              label: "工作日天数",
              component: "NumberInput",
              icon: "exposure",
              width: 4,
              defaultValue: 1,
            },
            {
              key: "weekends",
              label: "包含周末",
              component: "CheckButton",
              width: 4,
              defaultValue: false,
            },
            {
              key: "holidays",
              label: "节假日",
              component: "ArrayEditor",
              icon: "event_busy",
              width: 12,
              placeholder: "['2024-01-01']",
            },
          ],
        },
        {
          value: "quickcomposer.data.time.between",
          label: "时间范围判断",
          icon: "date_range",
          config: [
            {
              key: "time",
              label: "判断时间",
              component: "VariableInput",
              icon: "schedule",
              width: 12,
              placeholder: "2024-01-01 或 now",
            },
            {
              key: "startTime",
              label: "开始时间",
              component: "VariableInput",
              icon: "schedule",
              width: 4,
              placeholder: "2024-01-01",
            },
            {
              key: "endTime",
              label: "结束时间",
              component: "VariableInput",
              icon: "schedule",
              width: 4,
              placeholder: "2024-02-01",
            },
            {
              key: "inclusive",
              label: "包含边界",
              component: "CheckButton",
              width: 4,
              defaultValue: true,
            },
          ],
        },
      ],
    },
  ],
};
